import lightGallery from 'lightgallery';
import { defineComponent, h, onMounted, onUnmounted, ref, watch } from 'vue';
import { useRoute } from 'vue-router';
import 'lightgallery/scss/lightgallery.scss';
const getImages = (images) => images.map(({ alt, srcset, src }) => ({
    alt,
    src,
    thumb: src || srcset,
    srcset,
    subHtml: alt,
}));
export default defineComponent({
    name: 'LightGallery',
    setup(_props, { slots }) {
        const route = useRoute();
        const container = ref(null);
        const instance = ref(null);
        let id;
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        const delay = new Promise((resolve) => setTimeout(() => resolve(), LIGHT_GALLERY_DELAY));
        const plugins = [];
        const pluginsStyles = [];
        if (LIGHT_GALLERY_AUTOPLAY) {
            plugins.push(import('lightgallery/plugins/autoplay/lg-autoplay.min.js'));
            pluginsStyles.push(import('lightgallery/scss/lg-autoplay.scss'));
        }
        if (LIGHT_GALLERY_FULLSCREEN) {
            plugins.push(import('lightgallery/plugins/fullscreen/lg-fullscreen.min.js'));
            pluginsStyles.push(import('lightgallery/scss/lg-fullscreen.scss'));
        }
        if (LIGHT_GALLERY_PAGER) {
            plugins.push(import('lightgallery/plugins/pager/lg-pager.min.js'));
            pluginsStyles.push(import('lightgallery/scss/lg-pager.scss'));
        }
        if (LIGHT_GALLERY_ROTATE) {
            plugins.push(import('lightgallery/plugins/rotate/lg-rotate.min.js'));
            pluginsStyles.push(import('lightgallery/scss/lg-rotate.scss'));
        }
        if (LIGHT_GALLERY_SHARE) {
            plugins.push(import('lightgallery/plugins/share/lg-share.min.js'));
            pluginsStyles.push(import('lightgallery/scss/lg-share.scss'));
        }
        if (LIGHT_GALLERY_THUMBNAIL) {
            plugins.push(import('lightgallery/plugins/thumbnail/lg-thumbnail.min.js'));
            pluginsStyles.push(import('lightgallery/scss/lg-thumbnail.scss'));
        }
        if (LIGHT_GALLERY_ZOOM) {
            plugins.push(import('lightgallery/plugins/zoom/lg-zoom.min.js'));
            pluginsStyles.push(import('lightgallery/scss/lg-zoom.scss'));
        }
        const initLightGallery = () => {
            const timeID = (id = new Date().getTime());
            Promise.all([
                Promise.all(plugins),
                Promise.all(pluginsStyles),
                delay,
            ]).then(([plugins]) => {
                if (timeID === id) {
                    instance.value?.destroy();
                    const images = Array.from(document.querySelectorAll(IMAGE_SELECTOR));
                    instance.value = lightGallery.default(container.value, {
                        ...LIGHT_GALLERY_OPTIONS,
                        dynamic: true,
                        dynamicEl: getImages(images),
                        // this is a licenseKey to make this project under MIT, special thanks to @Sachin
                        licenseKey: 'VSY7R-J@WED-CJY76-UMDXQ',
                        plugins: plugins.map(({ default: plugin }) => plugin),
                    });
                    images.forEach((image, index) => {
                        image.addEventListener('click', () => {
                            instance.value?.openGallery(index);
                        });
                    });
                }
            });
        };
        watch(() => route, () => initLightGallery());
        onMounted(() => initLightGallery());
        onUnmounted(() => instance.value?.destroy());
        return () => h('div', { ref: container, class: 'lightgallery-vuepress' }, slots.default?.());
    },
});
//# sourceMappingURL=LightGallery.js.map